﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerPlatformerController : PhysicsObject {

    public float maxSpeed = 7;
    public float jumpTakeOffSpeed = 7;
	public AudioClip soundJump;
	public AudioClip soundNoBolts;
	public GameObject letters;

    private SpriteRenderer spriteRenderer;
    private Animator animator;
	private FireInvoker fire;
	private bool splash = true;

    void Awake () 
    {
        spriteRenderer = GetComponent<SpriteRenderer> (); 
        animator = GetComponent<Animator> ();
		fire = GetComponent<FireInvoker>();
    }

	void Start()
	{
		GetComponent<GameLogic>().uiTime.enabled = false;
	}

	void HideSplash()
	{
		if (!splash)
			return;
		splash = false;
		GameLogic.instance.timeStart = Time.timeSinceLevelLoad;
		letters.SetActive(false);
		GetComponent<GameLogic>().uiBlend.enabled = false;
		GetComponent<GameLogic>().uiTime.enabled = true;
	}

    protected override void ComputeVelocity()
    {
        Vector2 move = Vector2.zero;

		var horz = Input.GetAxis ("Horizontal");
        move.x = horz;
		if (Mathf.Abs(horz) > 0.98f)
			HideSplash();

        if (Input.GetButton /*GetButtonDown*/ ("Jump") && grounded)
		{
			HideSplash();
			AudioSource.PlayClipAtPoint(soundJump, Camera.main.transform.position, 0.4f);
            velocity.y = jumpTakeOffSpeed;
        }
		else if (Input.GetButtonUp ("Jump")) 
        {
            if (velocity.y > 0)
			{
                velocity.y = velocity.y * 0.5f;
            }
        }

		if (Input.GetButtonDown("Fire1") && grounded)
		{
			HideSplash();
			if (GameLogic.instance.boltCount > 0)
			{
				if (animator != null)
					animator.SetTrigger("fire");
				StartCoroutine(fire.DoFire());
			}
			else
			{
				AudioSource.PlayClipAtPoint(soundNoBolts, Camera.main.transform.position);
			}
		}

        if(move.x > 0.01f)
        {
            if(spriteRenderer.flipX == true)
            {
                spriteRenderer.flipX = false;
            }
        } 
        else if (move.x < -0.01f)
        {
            if(spriteRenderer.flipX == false)
            {
                spriteRenderer.flipX = true;
            }
        }

		if (animator != null)
		{
        	animator.SetBool ("grounded", grounded);
        	animator.SetFloat ("velocityX", Mathf.Abs (velocity.x) / maxSpeed);
		}

        targetVelocity = move * maxSpeed;
    }
}